@@ -548,6 +548,25 @@ static int _alpm_chroot_read_from_child(alpm_handle_t *handle, int fd,
 	return 0;
 }
 
+static void _alpm_reset_signals(void)
+{
+	/* reset POSIX defined signals (see signal.h) */
+	/* there are likely more but there is no easy way
+	 * to get the full list of valid signals */
+	int *i, signals[] = {
+		SIGABRT, SIGALRM, SIGBUS, SIGCHLD, SIGCONT, SIGFPE, SIGHUP, SIGILL,
+		SIGINT, SIGKILL, SIGPIPE, SIGQUIT, SIGSEGV, SIGSTOP, SIGTERM, SIGTSTP,
+		SIGTTIN, SIGTTOU, SIGUSR1, SIGUSR2, SIGPOLL, SIGPROF, SIGSYS, SIGTRAP,
+		SIGURG, SIGVTALRM, SIGXCPU, SIGXFSZ,
+		0
+	};
+	struct sigaction def;
+	def.sa_handler = SIG_DFL;
+	for(i = signals; *i; i++) {
+		sigaction(*i, &def, NULL);
+	}
+}
+
 /** Execute a command with arguments in a chroot.
  * @param handle the context handle
  * @param cmd command to execute
@@ -633,6 +652,7 @@ int _alpm_run_chroot(alpm_handle_t *handle, const char *cmd, char *const argv[],
 			exit(1);
 		}
 		umask(0022);
+		_alpm_reset_signals();
 		execv(cmd, argv);
 		/* execv only returns if there was an error */
 		fprintf(stderr, _("call to execv failed (%s)\n"), strerror(errno));
@@ -645,6 +665,7 @@ int _alpm_run_chroot(alpm_handle_t *handle, const char *cmd, char *const argv[],
 		ssize_t olen = 0, ilen = 0;
 		nfds_t nfds = 2;
 		struct pollfd fds[2], *child2parent = &(fds[0]), *parent2child = &(fds[1]);
+		int poll_ret;
 
 		child2parent->fd = child2parent_pipefd[TAIL];
 		child2parent->events = POLLIN;
@@ -665,7 +686,14 @@ int _alpm_run_chroot(alpm_handle_t *handle, const char *cmd, char *const argv[],
 #define STOP_POLLING(p) do { close(p->fd); p->fd = -1; } while(0)
 
 		while((child2parent->fd != -1 || parent2child->fd != -1)
-				&& poll(fds, nfds, -1) > 0) {
+				&& (poll_ret = poll(fds, nfds, -1)) != 0) {
+			if(poll_ret == -1) {
+				if(errno == EINTR) {
+					continue;
+				} else {
+					break;
+				}
+			}
 			if(child2parent->revents & POLLIN) {
 				if(_alpm_chroot_read_from_child(handle, child2parent->fd,
 							ibuf, &ilen, sizeof(ibuf)) != 0) {
