@@ -6,4 +6,4 @@ self.addpkg(p)
 self.args = "-U %s" % p.filename()
 
 self.addrule("PACMAN_RETCODE=0")
-self.addrule("FILE_EXIST=/etc/ld.so.cache")
+self.addrule("FILE_EXIST=etc/ld.so.cache")
